fnss.netconfig.buffers.set_buffer_sizes_constant — FNSS 0.1.2 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.1.2 documentation »
- API Reference »
- Functions »

# fnss.netconfig.buffers.set_buffer_sizes_constant

`set_buffer_sizes_constant`(topology, buffer_size, buffer_unit='bytes', interfaces=None)

  Assign a constant buffer size to all selected interfaces

  Parameters : | topology : Topology or DirectedTopology The topology on which buffer sizes are applied. buffer_size : int The constant buffer_size to be applied to all interface buffer_unit : string, unit The unit of buffer sizes. Supported units are: “bytes” and “packets” interfaces : list of tuples, optional The list of selected interfaces on which buffer sizes are applied. An interface is defined by the tuple (u,v) where u is the node on which the interface is located and (u,v) is the link to which the buffer flushes.

  Examples

      >>> import fnss
      >>> topology = fnss.Topology()
      >>> topology.add_path([1, 2, 4, 5, 8])
      >>> fnss.set_buffer_sizes_constant(topology, 100000, buffer_unit='bytes',     ... interfaces=[(1,2), (5,8), (4,5)])

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.1.2 documentation »
- API Reference »
- Functions »